#include <algorithm>
#include <iostream>
#include <random>
#include <vector>
#define endl '\n'
using namespace std;

mt19937 rg(93184134);

const int MAXN = 4000000;
const int C = 1e7;

int n;
long long ans;
int br[MAXN + 5];
long long b[MAXN + 5];
int a[MAXN + 5], pref[MAXN + 5];
pair<int, int> tree[4 * MAXN + 5];

struct Treap
{
    long long key;
    int sz, priority;
    Treap *l, *r;

    Treap(int key)
    {
        this -> key = key;
        priority = rg() % MAXN;
        l = r = nullptr;
        sz = 1;
    }

    void recalc()
    {
        sz = 1;
        if (l != nullptr) sz += l -> sz;
        if (r != nullptr) sz += r -> sz;
    }
};

Treap* rt[20 * MAXN + 5];

pair<Treap*, Treap*> Split(Treap* t, long long num)
{
    if (t == nullptr) return {nullptr, nullptr};

    if (t -> key <= num)
    {
        auto tmp = Split(t -> r, num);
        t -> r = tmp.first;
        t -> recalc();
        return {t, tmp.second};
    }
    else
    {
        auto tmp = Split(t -> l, num);
        t -> l = tmp.second;
        t -> recalc();
        return {tmp.first, t};
    }
}

Treap* Merge(Treap* sm, Treap* bg)
{
    if (sm == nullptr) return bg;
    if (bg == nullptr) return sm;

    if (sm -> priority > bg -> priority)
    {
        sm -> r = Merge(sm -> r, bg);
        sm -> recalc();
        return sm;
    }
    else
    {
        bg -> l = Merge(sm, bg -> l);
        bg -> recalc();
        return bg;
    }
}

void add(int idx, long long num)
{
    if (rt[idx] == nullptr)
    {
        rt[idx] = new Treap(num);
        return;
    }

    auto node = new Treap(num);
    auto tmp = Split(rt[idx], num);
    tmp.first = Merge(tmp.first, node);
    rt[idx] = Merge(tmp.first, tmp.second);
}

void rem(int idx, long long num)
{
    auto tmp = Split(rt[idx], num - 1);
    tmp.second = Split(tmp.second, num).second;
    rt[idx] = Merge(tmp.first, tmp.second);
}

int cnt(int idx, long long num)
{
    auto tmp = Split(rt[idx], num - 1);
    int ret = 0;
    if (tmp.second != nullptr) ret = tmp.second -> sz;
    rt[idx] = Merge(tmp.first, tmp.second);
    return ret;
}

long long get_min(Treap* t)
{
    if (t -> l == nullptr) return t -> key;
    return get_min(t -> l);
}

void build(int v, int l, int r)
{
    if (l == r)
    {
        tree[v] = {pref[l], l};
        return;
    }

    int mid = (l + r) / 2;
    build(2 * v, l, mid);
    build(2 * v + 1, mid + 1, r);
    tree[v] = tree[2 * v];
    tree[v] = max(tree[2 * v], tree[2 * v + 1]);
}

pair<int, int> query(int v, int l, int r, int ql, int qr)
{
    if (r < ql or qr < l) return {-MAXN, 0};
    if (ql <= l and r <= qr) return tree[v];

    int mid = (l + r) / 2;
    return max(query(2 * v, l, mid, ql, qr), query(2 * v + 1, mid + 1, r, ql, qr));
}

int num = 1;

int go(int l, int r)
{
    int idx = num++;
    if (r < l) return idx;

    int pos = query(1, 1, n, l, r).second;

    int idx1 = go(l, pos - 1), idx2 = go(pos + 1, r);
    add(idx2, b[pos]);

    ans += cnt(idx2, 1ll * C * (pref[pos] - pref[l - 1]));

    if (rt[idx1] == nullptr or rt[idx1] -> sz < rt[idx2] -> sz) swap(idx1, idx2);

    ///cout << l << " " << r << " " << t1 -> sz << " " << (t2 == nullptr ? 0 : t2 -> sz) << endl;

    ///cout << idx1 << " " << idx2 << endl;

    rt[idx] = rt[idx1];
    while (rt[idx2] != nullptr)
    {
        auto num = get_min(rt[idx2]);
        auto num2 = num / C;
        ///cout << num << endl;
        ans += cnt(idx1, 1ll * C * (pref[pos] - num2));
        ///cout << num << " " << ans << endl;
        rem(idx2, num);
        add(0, num);
    }
    while (rt[0] != nullptr)
    {
        auto num = get_min(rt[0]);
        rem(0, num);
        add(idx, num);
    }
    ///cout << l << " " << r << " " << ans << endl;
    ///cout << "------------------" << endl;
    return idx;
}

int main()
{
    ios :: sync_with_stdio(false);
    cin.tie(NULL); cout.tie(NULL);

    cin >> n;

    br[0] = 1;
    for (int i = 1; i <= n; ++ i)
    {
        char c;
        cin >> c;
        if (c == '(') a[i] = 1;
        else a[i] = -1;
        pref[i] = pref[i - 1] + a[i];
        b[i] = 1ll * C * pref[i] + br[pref[i]];
        br[pref[i]]++;
    }

    build(1, 1, n);

    go(1, n);

    cout << ans << endl;

    return 0;
}
